

*===============================================================================
* !!!!!!!!!!!! INPUT PATHS MANUALLY HERE
*===============================================================================

* Input path to project directory here
global dir "C:\Users\Public\Documents\TechBoom"

* Input path to CASD raw data here
global rawdatadir "\\casd.fr\casdfs\Projets\FISCENT\Data"



*===============================================================================
* DIRECTORIES AND PACKAGES
*===============================================================================

* create directory for raw data in stata format
cd "${dir}"
capture mkdir rawdata

* create directory for temporary files
cd "${dir}"
capture mkdir output

* create directory for results
cd "${dir}"
capture mkdir results

* install packages
do "${dir}/code/install_packages.do"



*===============================================================================
* EXTRACT AND CLEAN RAW DATA
*===============================================================================

*** DADS -----------------------------------------------------------------------

* create directory to store raw data in stata format
cd "${dir}/rawdata"
capture mkdir dads_panel
cd "${dir}/rawdata"
capture mkdir dads_postes
cd "${dir}/rawdata/dads_postes"
capture mkdir raw

/*
The DAS files are too big for Stata. Extract them using SAS. Run the SAS code in the following .txt file to extract:
1/ "DADS Panel" data
2/ "DADS Postes" data:

!!!!!! RUN THIS CODE IN SAS:   extract_dads.txt

*/

*** Business creation files ----------------------------------------------------

cd "${dir}"
do "code/extract_ree_creation.do"


*** Firm register --------------------------------------------------------------

cd "${dir}"
do "code/extract_ree_stock.do"


*** Corporate tax filings (Ficus-Fare) -----------------------------------------

* create directory to store raw data in stata format
cd "${dir}/rawdata"
capture mkdir ficus_fare
cd "${dir}/rawdata/ficus_fare"
capture mkdir raw

/*
Some files are too big for stata. Extract them using SAS.

!!!!!! RUN THIS CODE IN SAS:   extract_fare.txt

*/

cd "${dir}"
do "code/extract_ficus_fare.do"


*** Corporate ownership (Lifi) -------------------------------------------------

cd "${dir}"
do "code/extract_lifi.do"


*** New business survey (SINE) -------------------------------------------------

/*
cd "${dir}"
do "code/extract_sine.do"
*/



*===============================================================================
* CONSTRUCT VARIABLES
*===============================================================================

* Construct variables in the DADS panel
cd "${dir}"
do "code/variables_dads1.do"

* Construct firm variables in Ficus-Fare
cd "${dir}"
do "code/variables_firm.do"

* DADS postes
cd "${dir}"
do "code/extract_dads_postes.do"

* Construct additional variables and the final panel
cd "${dir}"
do "code/variables_dads2.do"



*===============================================================================
* DATA ANALYSIS
*===============================================================================

cd "${dir}"
do "code/analysis.do"

