
cd "${dir}"

******   LIST OF ICT SECTORS
{

*** List of ICT sectors 1994-2008 (Appendix Table B.2)

use year sir apet ict cs2 using "output/panel2015_full_dads", clear
keep if year>=1994 & year<=2008
drop if ict==.

gen sec4 = apet
gen sec3 = substr(apet,1,3)
gen sec2 = substr(apet,1,2)

gen ictsec1 = "Services" if sec2=="72" | sec4=="713E"
gen rank = 1 if ictsec1=="Services" // rank is a number for ictsec1, useful for editing the table by ictsec1
gen ictsec2 = " IT consultancy" if sec3=="721"
replace ictsec2 = " Software" if sec3=="722"
replace ictsec2 = " Data processing" if sec3=="723"
replace ictsec2 = " Maintenance computers" if sec3=="725"
replace ictsec2 = " Other computer-related services" if inlist(sec3,"724","726") | sec4=="713E"

replace ictsec1 = "Telecommunications" if sec3=="642"
replace rank = 2 if ictsec1=="Telecommunications"
replace ictsec2 = "  Telecommunications " if sec3=="642"

replace ictsec1 = "Manufacturing" if sec3=="300" | sec4=="313Z" | inlist(sec3,"321","322","323","332","333")
replace rank = 3 if ictsec1=="Manufacturing"
replace ictsec2 = "  Computing machinery" if sec3=="300"
replace ictsec2 = "  Insulated wire and cable" if sec4=="313Z"
replace ictsec2 = "  Electronic/communication equipment" if inlist(sec3,"321","322","323")
replace ictsec2 = "  Measurement/navigation/process control equipment" if inlist(sec3,"332","333")

replace ictsec1 = "Wholesale" if inlist(sec4,"516G","518G","518J")
replace rank = 4 if ictsec1=="Wholesale"
replace ictsec2 = " Computers, electronics, telecoms" if inlist(sec4,"516G","518G","518J")

replace rank = 0 if ictsec1=="" // non ICT

count if cs2==""
gen all = 1
gen ski = substr(cs2,1,1)=="3" | cs2=="23"

preserve
collapse (sum) all ski, by(ictsec1 rank)
foreach x in all ski {
egen tot`x' = sum(`x')
gen sh`x' = `x'/tot`x'*100
}
drop if rank==0
keep ictsec1 rank shall shski
save "output/temp", replace

restore
collapse (sum) all ski, by(ictsec2 rank)
foreach x in all ski {
egen tot`x' = sum(`x')
gen sh`x' = `x'/tot`x'*100
}
drop if rank==0
keep ictsec2 rank shall shski
append using "output/temp"

replace ictsec1 = "(1-digit) " + ictsec1 if ictsec1~=""
replace ictsec1 = "(2-digit) " + ictsec2 if ictsec1==""
gsort rank -shall

* create the table in the paper
l ictsec1 shall shski
* this is the last row of the table "ICT: Total"
egen totall = sum(shall) if substr(ictsec1,1,2)=="(1"
egen totski = sum(shski) if substr(ictsec1,1,2)=="(1"
sum totall totski

}


******   TIME-SERIES EMPLOYMENT SHARE
{

*** Summary stats all skilled workers (Appendix Table B.1 Panel A)
{

* all full-time workers 1994-2015
use "output/panel2015_full_dads", clear
keep if year>=1994 & year<=2015

* occupation level
gen broadoccup = "higher" if substr(cs2,1,1)=="3" | cs2=="23"
replace broadoccup = "inter" if substr(cs2,1,1)=="4"
replace broadoccup = "lower" if inlist(substr(cs2,1,1),"5","6")

* share of skilled in ICT vs. all industries
gen skilled = broadoccup=="higher" if cs2~="" & year<=2008
sum skilled
sum skilled if ict==1

* share of engineers in ICT vs. all industries
gen eng = cs2=="38" if skilled==1
sum eng
sum eng if ict==1

* real annual wage
merge m:1 year using "rawdata/inflation", keep(1 3) nogen
replace wage = wage * euro2000 * 12

* worker age
gen age = year-annai

* labels
label var wage "Annual wage"
label var sx "Male"
label var age "Age"

* summary stats for high-skill workers
eststo clear
estpost tabstat wage sx age if broadoccup=="higher", stat(N mean p25 p50 p75) col(stat)
estout using "results/TabB1a_sum-stats-all.tex", replace style(tex) cells("count(fmt(%12.0fc) label(N)) mean(fmt(%12.2f) label(Mean)) p25(fmt(%12.2f) label(P25)) p50(fmt(%12.2f) label(P50)) p75(fmt(%12.2f) label(P75))") label mlabels(none) varwidth(30)

* the median wage of high-skill (41,400 euros) correspond to the 90th percentile of the overall wage distribution
sum wage, d

}


*** Summary stats skilled entrants (Appendix Table B.1 Panel B)
{

use "output/entrants2015_fulltime", clear
keep if year0>=1994 & year0<=2005
keep if substr(occup0,1,1)=="3" | occup0=="23"

merge m:1 year using "rawdata/inflation.dta", keep(1 3) nogen
replace wage = wage * euro2000 * 12

sort nni year
by nni: gen wage0 = wage[1]

label var wage "Annual wage"
label var wage0 "Annual starting wage"
label var sx "Male"
gen age = year-annai
label var age "Age"
label var age0 "Age at entry"

eststo clear
estpost tabstat wage sx age0, stat(N mean p25 p50 p75) col(stat)
estout using "results\TabB1b_sum-stats-entrants.tex", replace style(tex) cells("count(fmt(%12.0fc) label(N)) mean(fmt(%12.2f) label(Mean)) p25(fmt(%12.2f) label(P25)) p50(fmt(%12.2f) label(P50)) p75(fmt(%12.2f) label(P75))") label mlabels(none) varwidth(30)

}

*** ICT employment share: all workers 1994-2008 (Figure 3)
{

use broadind nni annai year sir ict cs2 using "output/panel2015_full_dads", clear

* entry year
sort nni year
by nni: gen year0 = year[1] if year[1]>=1991 & year[1]-annai<=30

* keep 1994-2008
keep if year>=1994 & year<=2008
drop if ict==. | cs2==""

* define skilled workers
gen skilled = substr(cs2,1,1)=="3" | cs2=="23"
gen tech = cs2=="38" | cs2=="47"

* deal with changes in occupation classification at France Telecom: assign initial occupation throughout
sort nni sir year
by nni sir: gen skilled0 = skilled[1] if sir=="380129866"
replace skilled = 1 if sir=="380129866" & skilled0==1
by nni sir: gen tech0 = tech[1] if sir=="380129866"
replace tech = 1 if sir=="380129866" & tech0==1

* collapse by year
gen ict_all = ict
gen ict_ski = ict if skilled==1

gen ict_ski_inc = ict==1 & (year0<=year-5 | year0==.) if skilled==1
gen ict_ski_ent = ict==1 & (year0>=year-4 & year0~=.) if skilled==1

gen ict_ski_inc2 = ict==1 if skilled==1 & (year0<=year-5 | year0==.)
gen ict_ski_ent2 = ict==1 if skilled==1 & (year0>=year-4 & year0~=.)

gen ict_tec = ict if tech==1
gen ict_tec_inc = ict==1 & (year0<=year-5 | year0==.) if tech==1
gen ict_tec_ent = ict==1 & (year0>=year-4 & year0~=.) if tech==1
gen n = 1
collapse (mean) ict_all ict_ski ict_ski_inc ict_ski_ent ict_ski_inc2 ict_ski_ent2 ict_tec ict_tec_inc ict_tec_ent (sum) n skilled, by(year)
sum n skilled // to check confidentially criteria

label var ict_all "All"
label var ict_ski "Skilled"
label var ict_tec "Tech"

* Figure 3a
line ict_ski year, xlabel(1994(3)2006) xtitle("") ytitle("") ylabel(,angle(horizontal)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "results/Fig3a_ict_share_all-ski.pdf", as(pdf) replace

* Figure 3b
label var ict_ski_ent2 "0-4 years since entry"
label var ict_ski_inc2 "5+ years since entry"
line ict_ski_inc2 ict_ski_ent2 year, xlabel(1994(3)2006) xtitle("") ytitle("") ylabel(,angle(horizontal)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "results/Fig3b_ict_share_decomp2.pdf", as(pdf) replace

}

*** ICT employment share: entrants 1994-2008 (Appendix Figure B.1)
{

use "output/entrants2015_fulltime", clear
keep if year==year0			// keep entrants in their first year
keep if year>=1994 & year<=2008
gen ict_exft = ict if sir~="380129866" // exclude France Telecom

foreach x in ict ict_exft {
gen `x'_all = `x'
gen `x'_ski = `x' if substr(occup0,1,1)=="3" | occup0=="23"
gen `x'_tec = `x' if occup0=="38" | occup0=="47"
}

gen n = 1
gen skilled = substr(occup0,1,1)=="3" | occup0=="23"
gen tech = occup0=="38" | occup0=="47"
collapse (mean) ict_* (sum) n skilled tech, by(year)

* Appendix Figure B.1
line ict_ski year, xlabel(1994(3)2006) xtitle("") ytitle("") ylabel(,angle(horizontal)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "results/FigB1_ict_share_entrants-ski.pdf", as(pdf) replace

sum ict_ski if year>=1994 & year<=1996	// pre-boom period
local ratiopre = r(mean)
sum ict_ski if year>=1998 & year<=2001	// boom period
local ratioboom = r(mean)
sum ict_ski if year>=2003 & year<=2005	// post-boom period
local ratiopost = r(mean)
display `ratioboom'/`ratiopre'
display `ratioboom'/`ratiopost'

}

}


******   TIME-SERIES EQUITY ISSUANCE
{

*** Append Ficus-Fare files

clear
gen year = .
forvalues t = 1994(1)2006 {
append using "rawdata/ficus_fare/cleaned/ficus-fare`t'", keep(siren capisoc tot_act tactint ape stat_cj)
replace year = `t' if year==.
}

* legal status
gen cj1 = substr(stat_cj,1,1)
drop stat_cj

* ict
rename ape sec
gen ict = inlist(substr(sec,1,2),"72") | inlist(substr(sec,1,3),"300","321","322","323","332","333","642") | inlist(sec,"313Z","516G","518G","518J","713E") if sec~=""
drop if ict==.

* deal with negative capital
replace capisoc = 0 if capisoc<0

save "output/equity-issuance", replace


*** Equal-weighted issuance rate dropping firms below size threshold

use "output/equity-issuance", clear
drop if tot_act<0
gegen sir_num = group(sir)
gsort sir_num year
xtset sir_num year
gen dcap10_ = max(capisoc-L.capisoc,0)/L.tot_act if L.tot_act>=10
replace dcap10_ = 1 if dcap10_>1 & dcap10_<.
gcollapse (mean) dcap10_, by(ict year)
reshape wide dcap10_, i(year) j(ict)

label var dcap10_0 "Other sectors"
label var dcap10_1 "ICT sector"

line dcap10_1 dcap10_0 year, xlabel(1994(3)2006) xtitle("") ytitle("") ylabel(,angle(horizontal)) legend(region(lwidth(none))) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))

graph export "results/Fig2a_Agg_EquityIssuance.pdf", as(pdf) replace

}


******   TIME-SERIES STOCK VALUATION
{

use "output/firm_stock", clear

gegen sir = group(siren)
xtset sir year

* ict
rename ape sec
gen ict = inlist(substr(sec,1,2),"72") | inlist(substr(sec,1,3),"300","321","322","323","332","333","642") | inlist(sec,"313Z","516G","518G","518J","713E") if sec~=""

* stock price/sales ratio
gen PS = mktcapgr/cagr

* cumulative return
gen logret = log(1+return)

* lagged market cap
gen lmktcap = l.mktcap

* median P/S
gcollapse (p50) medPS=PS, by(ict year)

sort ict year
by ict: gen cumret = logret if _n==1
by ict: replace cumret = cumret[_n-1]+logret if _n>1
drop logret

reshape wide medPS cumret, i(year) j(ict)

label var medPS0 "Other sectors"
label var medPS1 "ICT sector"
label var cumret0 "Other sectors"
label var cumret1 "ICT sector"

line medPS1 medPS0 year, xlabel(1994(2)2006) xtitle("") ytitle("") ylabel(,angle(horizontal)) legend(region(lwidth(none))) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))

graph export "results/Fig1b_Agg_PS.pdf", as(pdf) replace

}


******   TIME-SERIES FIRM CREATION
{

*** Number of new firms (from creation files)

use "rawdata/ree_creation/cleaned/creation", clear
rename yearcrea year
keep if year>=1994 & year<=2006
rename sec_sine sec

* ict (industry classification is NAF 2003 rev 1 all along)
drop if sec==""
gen ict = inlist(substr(sec,1,2),"72") | inlist(substr(sec,1,3),"300","321","322","323","332","333","642") | inlist(sec,"313Z","516G","518G","518J","713E")
gen sec2 = substr(sec,1,2)

* business creation
gen crea_all = 1
gen cj1 = substr(cj_sine,1,1)
gen crea_soc = cj1=="5"

* collapse
gcollapse (sum) crea_*, by(sec2 ict year)

* reshape
reshape wide crea_*, i(sec2 year) j(ict)
foreach x in all soc {
	foreach s in 0 1 {
		replace crea_`x'`s' = 0 if crea_`x'`s'==.
	}
}

save "output/temp", replace


*** Stock of firms (from Ficus-Fare)

use sir year ape cj using "output/firm_all_var", clear
keep if year>=1994 & year<=2006

* ict (industry classification is NAF 1993 until 2001 and NAF 2003 rev 1 afterwards. the ICT definition below accommodates both classifications)
rename ape sec
drop if sec==""
gen ict = inlist(substr(sec,1,2),"72") | inlist(substr(sec,1,3),"300","321","322","323","332","333","642") | inlist(sec,"313Z","516G","518G","518J","713E")
gen sec2 = substr(sec,1,2)

* business creation
gen stock_all = 1
gen cj1 = substr(cj,1,1)
* incorporated businesses
gen stock_soc = cj1=="5"

* collapse
gcollapse (sum) stock_*, by(sec2 ict year)

* reshape
reshape wide stock_*, i(sec2 year) j(ict)
foreach x in all soc {
	foreach s in 0 1 {
		replace stock_`x'`s' = 0 if stock_`x'`s'==.
	}
}

* merge with firm creation
merge 1:1 sec2 year using "output/temp"

save "output/crea", replace


*** Figure: creation rate

use "output/crea", clear

foreach y in stock crea {
	foreach s in 0 1 {
		* restrict to 2-digit sectors with a match with both creation files and Ficus-Fare (this makes almost no difference between there are barely any obs in sectors with _m==1 or _m==2)
		qui gen `y'_soc`s'_mat = `y'_soc`s' if _m==3
	}
}

gcollapse (sum) stock_* crea_*, by(year)
foreach s in 0 1 {
	gen cr_soc`s' = crea_soc`s'_mat/stock_soc`s'_mat
}
label var cr_soc0 "Other sectors"
label var cr_soc1 "ICT sector"

line cr_soc1 cr_soc0 year, xlabel(1994(3)2006) xtitle("") ytitle("") ylabel(,angle(horizontal)) legend(region(lwidth(none))) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))

graph export "results/Fig2b_Agg_Crea.pdf", as(pdf) replace

}


***** CORRELATION CAPITAL FLOW / LABOR FLOW
{

* labor market entrants
use "output/entrants2015_fulltime", clear
keep if inlist(occup0,"23","37","38")
keep if year0>=1998 & year0<=2005
keep if year==year0
rename gcap_secdep gcap

* number of entrants at sector-departement-year level
gen n = 1
gcollapse (sum) n (mean) gcap, by(year ict0 apet0 dept0)

* add zeros
reshape wide n gcap, i(ict0 apet0 dept0) j(year)
forvalues t = 1998(1)2005 {
	replace n`t' = 0 if n`t'==0
}
reshape long n gcap, i(ict0 apet0 dept0) j(year)

* bring capital flow for observations where we added zeros
rename apet0 apet
rename dept0 dept
merge 1:1 apet dept year using "output/gcap_secdep", keep(2 3) nogen
keep if year>=1998 & year<=2005

* mid-point entry growth
gegen wn = sum(n/8), by(apet dept)
drop if wn==0
gen gn = n/wn

* RHS variables
gen gcap_ict0	= gcap*ict0
gen gcap_secdep_ict0 = gcap_secdep*ict0
label var gcap		"Capital flow"
label var gcap_secdep		"Capital flow"
label var gcap_ict0	"Capital flow \$\times$ ICT\$_0$"
label var gcap_secdep_ict0	"Capital flow \$\times$ ICT\$_0$"
label var ict0		"ICT\$_0$"

* regressions
eststo clear
foreach x in gcap {
qui eststo, title("`x'"): reghdfe gn `x' [aw=wn], a(apet dept year) cluster(apet dept year)
qui eststo, title("`x'"): reghdfe gn `x' `x'_ict0 [aw=wn], a(apet dept year) cluster(apet dept year)
}
estout using "results/TabB5_corr-flow.tex", replace style(tex) label cells(b(fmt(%8.2f)star) se(fmt(%8.2f)par)) starlevels(* 0.1 ** 0.05 *** 0.01) stat(r2_a N,fmt(%8.2g %8.0fc)label("Adjusted-R2" "Observations")) collabel(none) varwidth(40) drop(_cons)

* bin scatter
preserve
qui reghdfe gn [aw=wn], a(apet dept year) resid
predict gn_res, res
qui reghdfe gcap [aw=wn], a(apet dept year) resid
predict gcap_res, res
gquantiles gcap_20 = gcap_res [aw=wn], nq(20) xtile
gcollapse (mean) gn_res gcap_res [aw=wn], by(gcap_20)
capture drop fitted
reg gn_res gcap_res, r
predict fitted, xb
qui sum gcap_res
local xt = r(max)
local yt = _b[_cons]+r(max)*_b[gcap_res]+0.02
local tstat = round(_b[gcap_res]/_se[gcap_res],.2)
tw 	(sc gn_res gcap_res) (line fitted gcap_res), ///
	text(`yt' `xt' "t=`tstat'", color(maroon)) ///
	xtitle("Capital flow growth (residual)") ytitle("Labor flow growth (residual)") legend(off)
graph export "results/FigB2_CorrFlow.pdf", as(pdf) replace
restore

}


**********	REGRESSIONS   **********

*** FIGURES WAGE DYNAMICS
{

*** All cohorts

use "output/entrants2015_fulltime", clear
drop if coh==""
keep if inlist(occup0,"23","37","38")

* variable x cohort x year
foreach x in ict0 sx age0 age0sq {
foreach c in pre boom post {
forvalues t = 1994(1)2015 {
gen `x'_`c'_y`t' = `x' * (coh=="`c'") *  (year==`t')
}
}
}
egen occ0cohyr = group(occup0 coh year)
egen yr0yr = group(year0 year)

* individual FE
egen id = group(nni)

qui reghdfe logwage ict0_*_y* sx_*_y* age0_*_y* age0sq_*_y*, a(occ0cohyr yr0yr) cl(id)

* create figure
capture drop t
qui gen t = 1994+(_n-1) if 1994+(_n-1)<=2015
capture drop beta_* hi_* lo_*
foreach c in pre boom post {
qui gen beta_`c' = .
qui gen hi_`c' = .
qui gen lo_`c' = .
}
forvalues t = 1994(1)2015 {
qui replace beta_pre	= _b[ict0_pre_y`t'] if t==`t'
qui replace hi_pre		= _b[ict0_pre_y`t']+1.96*_se[ict0_pre_y`t'] if t==`t'
qui replace lo_pre	 	= _b[ict0_pre_y`t']-1.96*_se[ict0_pre_y`t'] if t==`t'
}
forvalues t = 1998(1)2015 {
qui replace beta_boom 	= _b[ict0_boom_y`t'] if t==`t'
qui replace hi_boom		= _b[ict0_boom_y`t']+1.96*_se[ict0_boom_y`t'] if t==`t'
qui replace lo_boom	 	= _b[ict0_boom_y`t']-1.96*_se[ict0_boom_y`t'] if t==`t'
}
forvalues t = 2003(1)2015 {
qui replace beta_post 	= _b[ict0_post_y`t'] if t==`t'
qui replace hi_post		= _b[ict0_post_y`t']+1.96*_se[ict0_post_y`t'] if t==`t'
qui replace lo_post	 	= _b[ict0_post_y`t']-1.96*_se[ict0_post_y`t'] if t==`t'
}

line beta_pre beta_boom beta_post t, ///
text(.09 1995.5 "Pre-boom", col(navy) size(small)) text(.08 1995.5 "cohort", col(navy) size(small)) xline(1994, lcol(navy) lpat(dot)) xline(1997, lcol(navy) lpat(dot)) ///
text(.09 2000 "Boom", col(maroon) size(small)) text(.08 2000 "cohort", col(maroon) size(small)) xline(1998, lcol(maroon) lpat(dot)) xline(2002, lcol(maroon) lpat(dot)) ///
text(.09 2004.5 "Post-boom", col(forest_green) size(small)) text(.08 2004.5 "cohort", col(forest_green) size(small)) xline(2003, lcol(forest_green) lpat(dot)) xline(2006, lcol(forest_green) lpat(dot)) ///
legend(off) xlabel(1994(3)2015) xtitle(" ") ylabel(-.1(.05).1, grid glwidth(vthin) glcolor(gs12)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))

graph export "results/Fig4_AllCohorts.pdf", as(pdf) replace


*** Boom minus Post

use "output/entrants2015_fulltime", clear
keep if inlist(coh,"boom","post")
keep if inlist(occup0,"23","37","38")
keep if year>=2003

* variable x cohort x year
foreach x in ict0 sx age0 age0sq {
foreach c in boom {
forvalues t = 2003(1)2015 {
gen `x'_`c'_y`t' = `x' * (coh=="`c'") *  (year==`t')
}
}
}
egen occ0cohyr = group(occup0 coh year)
egen yr0yr = group(year0 year)
egen ict0yr = group(ict0 year)

* individual FE
egen id = group(nni)

qui reghdfe logwage ict0_*_y* sx_*_y* age0_*_y* age0sq_*_y*, a(ict0yr occ0cohyr yr0yr) cl(id)

* create figure
capture drop t
qui gen t = 2003+(_n-1) if 2003+(_n-1)<=2015
capture drop beta_* hi_* lo_*
foreach c in boom {
qui gen beta_`c' = .
qui gen hi_`c' = .
qui gen lo_`c' = .
}
forvalues t = 2003(1)2015 {
qui replace beta_boom 	= _b[ict0_boom_y`t'] if t==`t'
qui replace hi_boom		= _b[ict0_boom_y`t']+1.96*_se[ict0_boom_y`t'] if t==`t'
qui replace lo_boom	 	= _b[ict0_boom_y`t']-1.96*_se[ict0_boom_y`t'] if t==`t'
}

line beta_boom hi_boom lo_boom t, lcolor(navy navy navy) lpattern(solid dash dash) ///
yline(0, lcol(black) lpat(solid) lwidth(thin)) ///
legend(off) xlabel(2003(3)2015) xtitle(" ") ylabel(-.1(.05).05, grid glwidth(vthin) glcolor(gs12)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))

graph export "results/Fig5a_BoomMinusPost.pdf", as(pdf) replace


*** Boom minus Pre

use "output/entrants2015_fulltime", clear
keep if inlist(coh,"boom","pre")
keep if inlist(occup0,"23","37","38")
keep if year>=1998

* variable x cohort x year
foreach x in ict0 sx age0 age0sq {
foreach c in boom {
forvalues t = 1998(1)2015 {
gen `x'_`c'_y`t' = `x' * (coh=="`c'") *  (year==`t')
}
}
}
egen occ0cohyr = group(occup0 coh year)
egen yr0yr = group(year0 year)
egen ict0yr = group(ict0 year)

* individual FE
egen id = group(nni)

qui reghdfe logwage ict0_*_y* sx_*_y* age0_*_y* age0sq_*_y*, a(ict0yr occ0cohyr yr0yr) cl(id)

* create figure
capture drop t
qui gen t = 1998+(_n-1) if 1998+(_n-1)<=2015
capture drop beta_* hi_* lo_*
foreach c in boom {
qui gen beta_`c' = .
qui gen hi_`c' = .
qui gen lo_`c' = .
}
forvalues t = 1998(1)2015 {
qui replace beta_boom 	= _b[ict0_boom_y`t'] if t==`t'
qui replace hi_boom		= _b[ict0_boom_y`t']+1.96*_se[ict0_boom_y`t'] if t==`t'
qui replace lo_boom	 	= _b[ict0_boom_y`t']-1.96*_se[ict0_boom_y`t'] if t==`t'
}

line beta_boom hi_boom lo_boom t, lcolor(navy navy navy) lpattern(solid dash dash) ///
yline(0, lcol(black) lpat(solid) lwidth(thin)) ///
legend(off) xlabel(1998(3)2015) xtitle(" ") ylabel(-.1(.05).1, grid glwidth(vthin) glcolor(gs12)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))

graph export "results/Fig5b_BoomMinusPre.pdf", as(pdf) replace

}
*


*** REGRESSIONS WAGE DYNAMICS
{

use "output/entrants2015_fulltime", clear
keep if inlist(occup0,"23","37","38")
keep if inlist(coh,"boom","post")

* individual FE
egen id = group(nni)
xtset id year

* initial wage quintile
gegen wage0 = max(wage*(year==year0)), by(id)
fasterxtile w0q = wage0, by(year0) nq(5)
drop wage0

* wage growth t-2 --> t
gen gwage = logwage - l2.logwage

* attrition: dummy last year in panel
gegen maxyear = max(year), by(id)
gen lastyear = year==maxyear
drop maxyear

* high valuation dummies (sector level in 1999)
rename r99v r99
rename meanPS PS
foreach var in r99 PS {
	qui gegen temp = pctile(`var') if year==year0, by(ict0) p(50)
	qui gegen tempp = max(temp), by(nni)
	qui gen `var'50 = `var'>=tempp if `var'<.
	drop temp*
}

* high equity flow dummies (sector-dept-year level)
rename gcap_secdep_l1o gcap
foreach var in gcap {
	qui gegen temp = pctile(`var') if year==year0, by(ict0 year) p(50)
	qui gegen tempp = max(temp), by(nni)
	qui gen `var'50 = `var'>=tempp if `var'<.
	drop temp*
}

* across-cohorts wage difference identified from 2003 onwards
keep if year>=2003

* periods
gen per = 1 if year>=1998 & year<=2001
replace per = 2 if year>=2002 & year<=2005
replace per = 3 if year>=2006 & year<=2010
replace per = 4 if year>=2011 & year<=2015

* controls interacted with cohort-year FE
gegen cohyr = group(coh year)
gegen sxcohyr = group(sx coh year)
gegen age0cohyr = group(age0 coh year)
gegen occ0cohyr = group(occup0 coh year)
gegen yr0yr = group(year0 year)
gegen w0qcohyr = group(w0q coh year)
gegen dep0yr = group(dept0 year)
gegen dep0cohyr = group(dept0 coh year)
gegen apet0yr = group(apet0 year)
gegen n32cohyr = group(naf32 coh year)
gegen apet0yr0yr = group(apet0 year0 year)
gegen dep0yr0yr = group(dept0 year0 year)

* ICT0 x cohort x year
gegen ict0yr = group(ict0 year)
forvalues t = 2(1)4 {
gen coh2_`t' = (coh=="boom") * (per==`t') * ict0
}
label var coh2_2 "ICT\$_0$ \$\times$ Boom cohort \$\times$ 2003-05"
label var coh2_3 "ICT\$_0$ \$\times$ Boom cohort \$\times$ 2006-10"
label var coh2_4 "ICT\$_0$ \$\times$ Boom cohort \$\times$ 2011-15"

* pseudo firms
fasterxtile quintile_L = L, by(year0) nq(5)
fasterxtile quintile_age = firmage0, by(year0) nq(5)
fasterxtile quintile_YL = YL, by(year0) nq(5)
fasterxtile quintile_gY5 = growth5yr, by(year0) nq(5)
foreach x in L age YL gY5 {
	replace quintile_`x' = 0 if quintile_`x'==.
}
gegen pseudofirm1 = group(quintile_L quintile_age quintile_YL busgrp)
gegen pseudofirm2 = group(quintile_L quintile_age quintile_YL quintile_gY5 busgrp)
gegen pfirm1yr = group(pseudofirm1 year)
gegen pfirm2yr = group(pseudofirm2 year)

* equity supply
forvalues t = 3(1)4 {
qui gen equi_`t' = .
qui gen equiboom_`t' = .
qui gen equiict0_`t' = .
qui gen equiict0boom_`t' = .
}
label var equi_3 "Capital availability \$\times$ 2006-10"
label var equi_4 "Capital availability \$\times$ 2011-15"
label var equiboom_3 "Capital availability \$\times$ Boom cohort \$\times$ 2006-10"
label var equiboom_4 "Capital availability \$\times$ Boom cohort \$\times$ 2011-15"
label var equiict0_3 "ICT\$_0$ \$\times$ Capital availability \$\times$ 2006-10"
label var equiict0_4 "ICT\$_0$ \$\times$ Capital availability \$\times$ 2011-15"
label var equiict0boom_3 "ICT\$_0$ \$\times$ Capital availability \$\times$ Boom cohort \$\times$ 2006-10"
label var equiict0boom_4 "ICT\$_0$ \$\times$ Capital availability \$\times$ Boom cohort \$\times$ 2011-15"




*** Baseline regressions

eststo clear
qui eststo, title("w/o FE_i"): 	reghdfe logwage coh2_*, a(ict0yr sxcohyr age0cohyr occ0cohyr yr0yr) cl(id)
qui eststo, title("w/ FE_i"):	reghdfe logwage coh2_3 coh2_4, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr) cl(id)
qui eststo, title("dep-coh-yr"):reghdfe logwage coh2_3 coh2_4, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr dep0cohyr) cl(id)
qui eststo, title("w0-coh-yr"): reghdfe logwage coh2_3 coh2_4, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr w0qcohyr) cl(id)
qui eststo, title("sec4-yr"): 	reghdfe logwage coh2_3 coh2_4, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr apet0yr) cl(id)
qui eststo, title("pfirm-yr"):	reghdfe logwage coh2_3 coh2_4, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr pfirm1yr) cl(id)
qui eststo, title("pfirmfwd-yr"):reghdfe logwage coh2_3 coh2_4, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr pfirm2yr) cl(id)
qui eststo, title("all"): 		reghdfe logwage coh2_3 coh2_4, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr w0qcohyr dep0cohyr apet0yr pfirm2yr) cl(id)
estout using "results/Tab1_wage.tex", replace style(tex) label cells(b(fmt(%8.3f)star) se(fmt(%8.3f)par)) starlevels(* 0.1 ** 0.05 *** 0.01) stat(r2_a N,fmt(%8.2g %8.0fc)label("Adjusted-R2" "Observations")) collabel(none) varwidth(50) drop(_cons)


*** Robustness

eststo clear
qui eststo, title("excl. fin"): reghdfe logwage coh2_3 coh2_4 if naf32~="JA", a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr) cl(id)
qui eststo, title("us"): reghdfe logwage coh2_3 coh2_4 if usa==1, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr) cl(id)
qui eststo, title("profit ceo"): reghdfe learnings_ceo coh2_3 coh2_4, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr) cl(id)
qui eststo, title("profit all"): reghdfe learnings_all coh2_3 coh2_4, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr) cl(id)
estout using "results/Tab2_robustness.tex", replace style(tex) label cells(b(fmt(%8.3f)star) se(fmt(%8.3f)par)) starlevels(* 0.1 ** 0.05 *** 0.01) stat(r2_a N,fmt(%8.2g %8.0fc)label("Adjusted-R2" "Observations")) collabel(none) varwidth(50) drop(_cons)


*** Attrition

gen gwage_ict0 = gwage * ict0
gen gwage_boom = gwage * (coh=="boom")
gen gwage_ict0_boom = gwage * ict0 * (coh=="boom")
label var gwage "Wage growth\$_{i,t-2 \rightarrow t}$"
label var gwage_ict0 "Wage growth\$_{i,t-2 \rightarrow t}$ \$\times$ ICT\$_0$"
label var gwage_boom "Wage growth\$_{i,t-2 \rightarrow t}$ \$\times$ Boom cohort"
label var gwage_ict0_boom "Wage growth\$_{i,t-2 \rightarrow t}$ \$\times$ ICT\$_0$ \$\times$ Boom cohort"

eststo clear
qui eststo, title("."): reghdfe lastyear gwage if year<=2010, a(ict0yr sxcohyr age0cohyr occ0cohyr yr0yr apet0yr) cl(id)
qui eststo, title("."): reghdfe lastyear gwage gwage_ict0 if year<=2010, a(ict0yr sxcohyr age0cohyr occ0cohyr yr0yr apet0yr) cl(id)
qui eststo, title("."): reghdfe lastyear gwage gwage_ict0 gwage_boom gwage_ict0_boom if year<=2010, a(ict0yr sxcohyr age0cohyr occ0cohyr yr0yr apet0yr) cl(id)
estout using "results/TabB4_attrition.tex", replace style(tex) label cells(b(fmt(%8.3f)star) se(fmt(%8.3f)par)) starlevels(* 0.1 ** 0.05 *** 0.01) stat(r2_a N,fmt(%8.2g %8.0fc)label("Adjusted-R2" "Observations")) collabel(none) varwidth(75) varlabel(_cons "Constant")


*** Equity supply

eststo clear
foreach x in r9950 PS50 gcap50 {
display "`x'"

forvalues t = 3(1)4 {
qui replace equi_`t' = `x' * (per==`t')
qui replace equiboom_`t' = `x' * (coh=="boom") * (per==`t')
qui replace equiict0_`t' = `x' * ict0 * (per==`t')
qui replace equiict0boom_`t' = `x' * ict0 * (coh=="boom") * (per==`t')
}

qui eststo, title("`x'"): reghdfe logwage coh2_3 coh2_4 equiict0boom_* equiict0_* equi_* equiboom_*, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr apet0yr dep0yr) cl(id)

}

qui eststo, title("sec4-coh-yr"): reghdfe logwage coh2_3 coh2_4 equiict0boom_* equiict0_* equi_* equiboom_*, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr apet0yr0yr dep0yr) cl(id)

qui eststo, title("dep-coh-yr"): reghdfe logwage coh2_3 coh2_4 equiict0boom_* equiict0_* equi_* equiboom_*, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr dep0yr0yr apet0yr) cl(id)

estout using "results/Tab3_equity.tex", replace style(tex) label cells(b(fmt(%8.3f)star) se(fmt(%8.3f)par)) starlevels(* 0.1 ** 0.05 *** 0.01) stat(r2_a N,fmt(%8.2g %8.0fc)label("Adjusted-R2" "Observations")) collabel(none) varwidth(80) keep(coh2_* equiict0boom_*)


*** Quantile regressions

capture drop _*
foreach t in 2 3 4 {
gen _ict0_`t' = ict0*(per==`t')
gen _sx_`t' = sx*(per==`t')
gen _sxboom_`t' = sx*(coh=="boom")*(per==`t')
gen _age0_`t' = age0*(per==`t')
gen _age0boom_`t' = age0*(coh=="boom")*(per==`t')
gen _age0sq_`t' = age0sq*(per==`t')
gen _age0sqboom_`t' = age0sq*(coh=="boom")*(per==`t')
gen _eng_`t' = (occup0=="38")*(per==`t')
gen _engboom_`t' = (occup0=="38")*(coh=="boom")*(per==`t')
foreach y0 in 1998 1999 2000 2001 2003 2004 2005 {
gen _`y0'_`t' = (year0==`y0')*(per==`t')
}
}

eststo clear
foreach q in 10 25 50 75 90 {
display "`q'"
qui eststo, title("p`q'"): xtqreg logwage coh2_3 coh2_4 _*, i(id) q(.`q')
}
estout using "results/Tab6a_quantile.tex", replace style(tex) label cells(b(fmt(%8.3f)star) se(fmt(%8.3f)par)) starlevels(* 0.1 ** 0.05 *** 0.01) stat(r2_a N,fmt(%8.2g %8.0fc)label("Adjusted-R2" "Observations")) collabel(none) varwidth(50) drop(_*)


forvalues t = 3(1)4 {
qui replace equi_`t' = gcap50 * (per==`t')
qui replace equiboom_`t' = gcap50 * (coh=="boom") * (per==`t')
qui replace equiict0_`t' = gcap50 * ict0 * (per==`t')
qui replace equiict0boom_`t' = gcap50 * ict0 * (coh=="boom") * (per==`t')
}

eststo clear
foreach q in 10 25 50 75 90 {
display "`q'"
qui eststo, title("p`q'"): xtqreg logwage coh2_3 coh2_4 equiict0boom_* equiict0_* equi_* equiboom_* _*, i(id) q(.`q')
}

estout using "results/Tab6b_quantile-equity.tex", replace style(tex) label cells(b(fmt(%8.3f)star) se(fmt(%8.3f)par)) starlevels(* 0.1 ** 0.05 *** 0.01) stat(r2_a N,fmt(%8.2g %8.0fc)label("Adjusted-R2" "Observations")) collabel(none) varwidth(80) drop(equiict0_* equi_* equiboom_* _*)

drop _*

*
}
*


*** LOWER SKILLS
{

use "output/entrants2015_fulltime", clear
keep if inlist(coh,"boom","post")

* occupations
gen occup0cat 		= "hi" if inlist(occup0,"23","37","38")
replace occup0cat	= "med" if inlist(occup0,"46","47","48")
replace occup0cat	= "lo" if inlist(occup0,"54","55")
keep if occup0cat~=""

* high equity flow dummies (sector-dept-year level)
rename gcap_secdep_l1o gcap
foreach var in gcap {
	qui gegen temp = pctile(`var') if year==year0, by(ict0 year occup0cat) p(50)
	qui gegen tempp = max(temp), by(nni)
	qui gen `var'50 = `var'>=tempp if `var'<.
	drop temp*
}

keep if year>=2003

* periods
gen per = 1 if year>=1998 & year<=2001
replace per = 2 if year>=2002 & year<=2005
replace per = 3 if year>=2006 & year<=2010
replace per = 4 if year>=2011 & year<=2015

* controls interacted with cohort-year FE
gegen cohyr = group(coh year)
gegen sxcohyr = group(sx coh year)
gegen age0cohyr = group(age0 coh year)
gegen occ0cohyr = group(occup0 coh year)
gegen yr0yr = group(year0 year)
gegen dep0yr = group(dept0 year)
gegen dep0cohyr = group(dept0 coh year)
gegen apet0yr = group(apet0 year)
gegen n32cohyr = group(naf32 coh year)
gegen apet0yr0yr = group(apet0 year0 year)
gegen dep0yr0yr = group(dept0 year0 year)

* individual FE
gegen id = group(nni)

* ICT0 x cohort x year
gegen ict0yr = group(ict0 year)
forvalues t = 3(1)4 {
gen coh2_`t' = (coh=="boom") * (per==`t') * ict0
}
label var coh2_3 "ICT\$_0$ \$\times$ Boom cohort \$\times$ 2006-10"
label var coh2_4 "ICT\$_0$ \$\times$ Boom cohort \$\times$ 2011-15"

* interactions with equity
forvalues t = 3(1)4 {
qui gen equi_`t' = .
qui gen equiboom_`t' = .
qui gen equiict0_`t' = .
qui gen equiict0boom_`t' = .
}
label var equi_3 "Capital flow \$\times$ 2006-10"
label var equi_4 "Capital flow \$\times$ 2011-15"
label var equiboom_3 "Capital flow \$\times$ Boom cohort \$\times$ 2006-10"
label var equiboom_4 "Capital flow \$\times$ Boom cohort \$\times$ 2011-15"
label var equiict0_3 "ICT\$_0$ \$\times$ Capital flow \$\times$ 2006-10"
label var equiict0_4 "ICT\$_0$ \$\times$ Capital flow \$\times$ 2011-15"
label var equiict0boom_3 "ICT\$_0$ \$\times$ Capital flow \$\times$ Boom cohort \$\times$ 2006-10"
label var equiict0boom_4 "ICT\$_0$ \$\times$ Capital flow \$\times$ Boom cohort \$\times$ 2011-15"



*** Regressions by skill level

eststo clear
foreach occ in hi med lo {
display "`occ'"

forvalues t = 3(1)4 {
qui replace equi_`t' = gcap50 * (per==`t')
qui replace equiboom_`t' = gcap50 * (coh=="boom") * (per==`t')
qui replace equiict0_`t' = gcap50 * ict0 * (per==`t')
qui replace equiict0boom_`t' = gcap50 * ict0 * (coh=="boom") * (per==`t')
}

qui eststo, title("`occ'"): reghdfe logwage coh2_3 coh2_4 if occup0cat=="`occ'", a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr) cl(id)
qui eststo, title("`occ'"): reghdfe logwage coh2_3 coh2_4 equiict0boom_* equiict0_* equi_* equiboom_* if occup0cat=="`occ'", a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr dep0yr apet0yr) cl(id)

}

estout using "results/Tab4_skill-equity.tex", replace style(tex) label cells(b(fmt(%8.3f)star) se(fmt(%8.3f)par)) starlevels(* 0.1 ** 0.05 *** 0.01) stat(r2_a N,fmt(%8.2g %8.0fc)label("Adjusted-R2" "Observations")) collabel(none) varwidth(80) keep(coh2_* equiict0boom_*)

}



*** JOB MOBILITY: LHS = MOBILITY
{

use "output/entrants2015_fulltime", clear
keep if inlist(occup0,"23","37","38")
keep if inlist(coh,"boom","post")

* forced termination: time-varying definition
drop term_all termsec_all
gegen term_all = max((term==1)*(year<=year0+3)), by(nni)
gegen term_de10 = max((term==1)*(term_gemp_ficus<-.1)*(year<=year0+3)), by(nni)
gegen term_dw = max((term==1)*(next_wage<wage)*(year<=year0+3)), by(nni)

gegen termsec_all = max((term==1)*(year<=year0+3)*(changesec==1)), by(nni)
gegen termsec_de10 = max((term==1)*(term_gemp_ficus<-.1)*(year<=year0+3)*(changesec==1)), by(nni)
gegen termsec_dw = max((term==1)*(next_wage<wage)*(year<=year0+3)*(changesec==1)), by(nni)

* keep 1 obs per worker
bys nni: keep if _n==1

gen loss = term_de10==1 | term_dw==1

* RHS
gen ict0_boom = ict0*(coh=="boom")
label var ict0 "ICT\$_0$"
label var ict0_boom "ICT\$_0$ x Boom cohort"
gegen sxcoh = group(sx coh)
gegen age0coh = group(age0 coh)
gegen occ0coh = group(occup0 coh)
gegen dep0coh = group(dept0 coh)


eststo clear
foreach x in term_all term_de10 term_dw loss {
qui eststo, title("`x'"): reghdfe `x' ict0_boom ict0, a(sxcoh age0coh occ0coh) vce(r)
}
estout using "results/TabB7_jobloss.tex", replace style(tex) label cells(b(fmt(%8.2g)star) se(fmt(%8.2g)par)) starlevels(* 0.1 ** 0.05 *** 0.01) stat(r2_a N,fmt(%8.2g %8.0fc)label("Adjusted-R2" "Observations")) collabel(none) varwidth(25) drop(_cons)

}
*


*** JOB MOBILITY: LHS = WAGE
{

use "output/entrants2015_fulltime", clear
keep if inlist(occup0,"23","37","38")
keep if inlist(coh,"boom","post")

* forced termination (employer job drop or employee wage drop)
gen term_t = (term==1) & ((term_gemp_ficus<-.1) | (next_wage<wage))
gegen term_4 = max(term_t*(year<=year0+3)), by(nni)

* forced termination (employer job drop)
gen term_demp_t = (term==1) & (term_gemp_ficus<-.1)
gegen term_demp_4 = max(term_demp_t*(year<=year0+3)), by(nni)

* forced termination (employee wage drop)
gen term_dw_t = (term==1) & (next_wage<wage)
gegen term_dw_4 = max(term_dw_t*(year<=year0+3)), by(nni)

* any sector change
gen termsec_t = (term==1) & (changesec==1)
gegen termsec_4 = max(termsec_t*(year<=year0+3)), by(nni)

* forced termination + sector change
gen termsec_demp_t = (term==1) & (term_gemp_ficus<-.1) & (changesec==1)
gegen termsec_demp_4 = max(termsec_demp_t*(year<=year0+3)), by(nni)
gen termsec_dw_t = (term==1) & (next_wage<wage) & (changesec==1)
gegen termsec_dw_4 = max(termsec_dw_t*(year<=year0+3)), by(nni)

* high equity flow dummies (sector-dept-year level)
rename gcap_secdep_l1o gcap
foreach var in gcap {
	qui gegen temp = pctile(`var') if year==year0, by(ict0 year) p(50)
	qui gegen tempp = max(temp), by(nni)
	qui gen `var'50 = `var'>=tempp if `var'<.
	drop temp*
}

keep if year>=2003

* periods
gen per = 1 if year>=1998 & year<=2001
replace per = 2 if year>=2002 & year<=2005
replace per = 3 if year>=2006 & year<=2010
replace per = 4 if year>=2011 & year<=2015

* fixed effects
gegen cohyr = group(coh year)
gegen sxcohyr = group(sx coh year)
gegen age0cohyr = group(age0 coh year)
gegen occ0cohyr = group(occup0 coh year)
gegen yr0yr = group(year0 year)
gegen dep0cohyr = group(dept0 coh year)
gegen dep0yr = group(dept0 year)
gegen apet0yr = group(apet0 year)
gegen n32cohyr = group(naf32 coh year)
gegen id = group(nni)

* ICT0 x cohort x year
gegen ict0yr = group(ict0 year)
forvalues t = 2(1)4 {
gen coh2_`t' = (coh=="boom") * (per==`t') * ict0
}


forvalues t = 3(1)4 {
qui gen mob_`t' = .
qui gen mobboom_`t' = .
qui gen mobict0_`t' = .
qui gen mobict0boom_`t' = .

qui gen equi_`t' = .
qui gen equimob_`t' = .
qui gen equiict0_`t' = .
qui gen equiboom_`t' = .
qui gen equimobboom_`t' = .
qui gen equimobict0_`t' = .
qui gen equiict0boom_`t' = .
qui gen equimobict0boom_`t' = .
}

label var coh2_3 "ICT\$_0$ \$\times$ Boom cohort \$\times$ 2006-10"
label var coh2_4 "ICT\$_0$ \$\times$ Boom cohort \$\times$ 2011-15"
label var mob_4 "Job loss \$\times$ 2011-15"
label var mobboom_4 "Job loss \$\times$ Boom cohort \$\times$ 2011-15"
label var mobict0_4 "Job loss \$\times$ ICT\$_0$ \$\times$ 2011-15"
label var mobict0boom_4 "ICT\$_0$ \$\times$ Job loss \$\times$ Boom cohort \$\times$ 2011-15"

label var equi_4 "Capital flow \$\times$ 2011-15"
label var equiboom_4 "Capital flow \$\times$ Boom cohort \$\times$ 2011-15"
label var equiict0_4 "ICT\$_0$ \$\times$ Capital flow \$\times$ 2011-15"
label var equiict0boom_3 "ICT\$_0$ \$\times$ Capital flow \$\times$ Boom cohort \$\times$ 2006-10"
label var equiict0boom_4 "ICT\$_0$ \$\times$ Capital flow \$\times$ Boom cohort \$\times$ 2011-15"

label var equimob_4 "Capital flow \$\times$ Job loss \$\times$ 2011-15"
label var equimobboom_4 "Capital flow \$\times$ Job loss \$\times$ Boom cohort \$\times$ 2011-15"
label var equimobict0_4 "Capital flow \$\times$ Job loss \$\times$ ICT\$_0$ \$\times$ 2011-15"
label var equimobict0boom_4 "Capital flow \$\times$ ICT\$_0$ \$\times$ Job loss \$\times$ Boom cohort \$\times$ 2011-15"

foreach x in term_4 {

eststo clear

forvalues t = 3(1)4 {
qui replace mob_`t' = (`x'==1) * (per==`t')
qui replace mobboom_`t' = (`x'==1) * (per==`t') * (coh=="boom")
qui replace mobict0_`t' = (`x'==1) * (per==`t') * ict0
qui replace mobict0boom_`t' = (`x'==1) * (per==`t') * (coh=="boom") * ict0

qui replace equi_`t' = gcap50 * (per==`t')
qui replace equimob_`t' = gcap50 * (`x'==1) * (per==`t')
qui replace equiict0_`t' = gcap50 * ict0 * (per==`t')
qui replace equiboom_`t' = gcap50 * (coh=="boom") * (per==`t')
qui replace equimobboom_`t' = gcap50 * (`x'==1) * (coh=="boom") * (per==`t')
qui replace equimobict0_`t' = gcap50 * (`x'==1) * ict0 * (per==`t')
qui replace equiict0boom_`t' = gcap50 * ict0 * (coh=="boom") * (per==`t')
qui replace equimobict0boom_`t' = gcap50 * (`x'==1) * ict0 * (coh=="boom") * (per==`t')
}

qui eststo, title("."): reghdfe logwage coh2_3 coh2_4, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr) cl(id)
qui eststo, title("."): reghdfe logwage coh2_3 coh2_4 mob_*, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr) cl(id)
qui eststo, title("."): reghdfe logwage coh2_3 coh2_4 mob_* mobict0_* mobboom_* mobict0boom_*, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr) cl(id)

qui eststo, title("."): reghdfe logwage coh2_3 coh2_4 equiict0boom_* equiict0_* equi_* equiboom_*, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr apet0yr dep0yr) cl(id)
qui eststo, title("."): reghdfe logwage coh2_3 coh2_4 equiict0boom_* equiict0_* equi_* equiboom_* mob_* equimob_*, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr apet0yr dep0yr) cl(id)
qui eststo, title("."): reghdfe logwage coh2_3 coh2_4 equiict0boom_* equiict0_* equi_* equiboom_* mob_* mobboom_* mobict0boom_* equimob_* mobict0_* equimobict0_* equimobboom_* equimobict0boom_*, a(id ict0yr sxcohyr age0cohyr occ0cohyr yr0yr apet0yr dep0yr) cl(id)

estout using "results/Tab5_wage-jobloss.tex", replace style(tex) label cells(b(fmt(%8.3f)star) se(fmt(%8.3f)par)) starlevels(* 0.1 ** 0.05 *** 0.01) stat(r2_a N,fmt(%8.2g %8.0fc)label("Adjusted-R2" "Observations")) collabel(none) varwidth(70) keep(coh2_* equiict0boom_*)

estout using "results/TabB6_wage-jobloss-allvar.tex", replace style(tex) label cells(b(fmt(%8.3f)star) se(fmt(%8.3f)par)) starlevels(* 0.1 ** 0.05 *** 0.01) stat(r2_a N,fmt(%8.2g %8.0fc)label("Adjusted-R2" "Observations")) collabel(none) varwidth(80) drop(_cons *_3)

}


}
*


*** CUMULATIVE EARNINGS
{

use "output/entrants2015_fulltime", clear
keep if inlist(coh,"boom")
keep if inlist(occup0,"23","37","38")
keep nni coh ict0 year0 age0 age0sq sx occup0 dept0 apet0
bys nni : keep if _n==1

* cumulative earnings at worker-year level (with no gap years in the panel)
merge 1:m nni using "output/cumulative_earnings", nogen keep(3) keepusing(year pv*)

* log of PV of earnings from entry up to current year
foreach x in 0 1 2 {
gen lpv`x' = log(pv`x')
}

* interactions
forvalues y = 1998(1)2015 {
qui gen ict0_`y' = ict0 * (year==`y')
label var ict0_`y' "ICT\$_0$ \$\times$ `y'"
}

egen id = group(nni)
egen sxyr = group(sx year)
egen age0yr = group(age0 year)
egen yr0yr = group(year0 year)
egen occ0yr = group(occup0 year)
gegen dep0yr = group(dept0 year)

eststo clear
qui eststo, title("log"): reghdfe lpv0 ict0_*, a(sxyr age0yr occ0yr yr0yr) vce(cluster id)
qui eststo, title("level"): reghdfe pv0 ict0_*, a(sxyr age0yr occ0yr yr0yr) vce(cluster id)
qui eststo, title("1yr UB"): reghdfe pv1 ict0_*, a(sxyr age0yr occ0yr yr0yr) vce(cluster id)
estout using "results/TabB3_cumulative.tex", replace style(tex) label cells(b(fmt(%8.2g)star) se(fmt(%8.2g)par)) starlevels(* 0.1 ** 0.05 *** 0.01) stat(r2_a N,fmt(%8.2g %8.0fc) label("Adjusted-R2" "Observations")) collabel(none) varwidth(30) drop(_cons ict0_1998 ict0_1999 ict0_2000 ict0_2002 ict0_2003 ict0_2004 ict0_2006 ict0_2007 ict0_2008 ict0_2009 ict0_2011 ict0_2012 ict0_2013 ict0_2014)

}
*

