
*-------------------------------------------------------------------------------
* Start from the micro data and create aggregate at the year level
*-------------------------------------------------------------------------------

foreach year in 1990 2000 2010 {
	* raw CPS data
	use "source/cps`year's", clear
	keep if year >= 1995
	keep if age >=20 & age<= 65	// working age
	keep if educ >= 90 			// at least high school degree
	keep if empstat ==10  		// employed
	gen college4 = educ>=110	// college degree
	gen under30	= age<30		// under 30
	
	* ICT dummy
	gen ict = 0
	replace ict = 1 if ind1990 == 322 | ind1990 >= 340 & ind1990 <= 350 | ind1990 == 371 | ind1990 >= 440 & ind1990 <= 442 | ind1990 == 633 | ind1990 == 732 | occ2010==0110 | occ2010==0700 | occ2010>=1000 & occ2010<=1540
	gen nict= 1-ict
	
	* Keep college educated
	keep if college4==1
	
	* employment by ICT - age and education 
	foreach var in ict nict {
		gen `var'_emp				= `var'* wtsupp
		gen `var'_empUnder30		= `var'* wtsupp*under30
		gen `var'_empOver30			= `var'* wtsupp*(1-under30)
	}
	gcollapse (sum) ict_* nict_*, by(year)
	save "`year'ict", replace
}


*-------------------------------------------------------------------------------
* Generate Appendix Figure C.1
*-------------------------------------------------------------------------------

* Aggregated CPS data
use "1990ict", clear
append using "2000ict"
append using "2010ict"

* Sample period
drop if year>2015

* Share ICT
foreach var in _emp _empUnder30 _empOver30 {
	gen S`var' = ict`var'/(ict`var'+nict`var')
}
keep if year<=2010

* Figure C.1
label var S_empUnder30 "Under 30"
label var S_empOver30 "Over 30"
graph twoway ///
	(line S_empUnder30 year, lwidth(medthick) lcolor(maroon)) ///
	(line S_empOver30 year, lwidth(medthick) lcolor(navy%80)) ///
	, xtitle("") ytitle("") ylabel(,nogrid angle(horizontal)) 	///
	legend(position(6) row(1) region(lwidth(none))) 	///
	graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))

graph export "FigC1_ict_emp.pdf", as(pdf) replace
